@@ -1,7 +1,4 @@
-try:
-    import json
-except ImportError:
-    from django.utils import simplejson as json
+import json
 
 from respite.serializers.jsonserializer import JSONSerializer
 
