@@ -1,10 +1,7 @@
-try:
-    import json
-except ImportError:
-    from django.utils import simplejson as json
-    
+import json
+
 from respite.serializers.base import Serializer
-    
+
 class JSONSerializer(Serializer):
 
     def serialize(self, request):
