@@ -1,7 +1,8 @@
 from copy import deepcopy
 
-from django.conf.urls.defaults import *
+from django.conf.urls import *
 from django.http import HttpResponse
+from django.utils.translation import string_concat
 
 from respite.inflector import pluralize, cc2us
 
@@ -94,13 +95,12 @@ def resource(views, routes, prefix=''):
             if callable(route.regex):
                 routes[i].regex = route.regex(prefix)
             else:
-                routes[i].regex = '^%s' % prefix + (route.regex[1:] if route.regex[0] == '^' else route.regex)
+                routes[i].regex = string_concat('^', prefix, route.regex)
 
             if callable(route.name):
                 routes[i].name = route.name(views)
 
         for route in list(routes):
-
             # Collect this route and its siblings (i.e. routes that share
             # same regular expression) in a dictionary of keys that describe
             # HTTP methods and values that describe the corresponding
